==> plee-the-bear_0.4.1.orig.tar.gz: plee-the-bear-0.4.1/plee-the-bear/src/ptb/item/code/player_killer.cpp <==
/*
  Bear Engine

  Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file player_killer.cpp
 * \brief Implementation of the bear::player_killer class.
 * \author Julien Jorge
 */
#include "ptb/item/player_killer.hpp"

#include "universe/collision_info.hpp"
#include "engine/export.hpp"
#include "ptb/item/plee/plee.hpp"
#include "ptb/player_action.hpp"

BASE_ITEM_EXPORT( player_killer, ptb )

/*----------------------------------------------------------------------------*/
/**
 * \brief Kill \a that if it is a player.
 * \param that The other item of the collision.
 * \param info Some informations about the collision.
 */
void ptb::player_killer::collision
( bear::engine::base_item& that, bear::universe::collision_info& info )
{
  plee* p = dynamic_cast<plee*>(&that);

  if ( p )
    p->start_action( player_action::die );
} // player_killer::collision()

==> plee-the-bear_0.5.1.orig.tar.gz: plee-the-bear-0.5.1/plee-the-bear/src/ptb/item/code/player_killer.cpp <==
/*
  Plee the Bear

  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file player_killer.cpp
 * \brief Implementation of the bear::player_killer class.
 * \author Julien Jorge
 */
#include "ptb/item/player_killer.hpp"

#include "universe/collision_info.hpp"
#include "engine/export.hpp"
#include "ptb/player.hpp"
#include "ptb/player_action.hpp"

BASE_ITEM_EXPORT( player_killer, ptb )

/*----------------------------------------------------------------------------*/
/**
 * \brief Kill \a that if it is a player.
 * \param that The other item of the collision.
 * \param info Some informations about the collision.
 */
void ptb::player_killer::collision
( bear::engine::base_item& that, bear::universe::collision_info& info )
{
  player* p = dynamic_cast<player*>(&that);

  if ( p )
    p->start_action( player_action::die );
} // player_killer::collision()
